Learn R Programming

LePage (version 1.0)

col.lepage: Column-wise LePage type tests

Description

Column-wise LePage type tests

Usage

col.lepage(x, y)

Value

A list including:

statistic

A matrix with 6 columns, where each column contains each test statistic and each row refers to the pair of groups.

pvalue

A matrix with 6 columns, where each column contains each p-value and each row refers to the pair of groups.

Arguments

x

A numerical matrix with data, where each column corresponds to the first sample.

y

A numerical matrix with data, where each column corresponds to the second sample.

Author

Abid Hussain and Michail Tsagris.

R implementation and documentation: Abid Hussain abid0100@gmail.com and Michail Tsagris mtsagris@uoc.gr.

Details

The classical LePage and 5 variants of it are performed, as proposed by Hussain and Tsagris (2025). The test is performed for each pair of columns of the x and y matrices, between the i-th column of and y.

References

Hussain A. and Tsagris M. (2025). Modified Lepage-type test statistics for the weak null hypothesis. https://arxiv.org/pdf/2509.19126

See Also

lepage

Examples

Run this code
x <- matrix( rnorm(30 * 5), ncol = 5 )
y <- matrix( rnorm(31 * 5), ncol = 5 )
col.lepage(x, y)

Run the code above in your browser using DataLab